@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * $Id: tclDomProInt.h,v 1.10 2002/02/22 02:28:34 jenglish Exp $
+ * $Id: tclDomProInt.h,v 1.13 2003/12/03 20:18:43 balls Exp $
  */
 
 #ifndef _TCLDOMPROINT
@@ -19,10 +19,11 @@
 #include <ctype.h>
 #include <memory.h>
 #include <string.h>
-#include <xmlparse.h>
 #include <stddef.h>
 #include "tdp.h"
 
+#include <expat.h>
+
 
 /*
  * Define position of the reference node with respect
@@ -347,17 +348,18 @@ typedef struct _TclDomInterpData {
     TclDomExpatInfo parserInfo;
 } TclDomInterpData;
 
-#ifdef BUILD_tcldompro
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS DLLEXPORT
+#ifdef BUILD_tcldom
+#	define TCLDOMAPI DLLEXPORT
+#else
+#	define TCLDOMAPI
 #endif
 
 /*
  * Declarations for externally visible functions.
  */
 
-EXTERN int 	Tcldom_Init(Tcl_Interp *interp);
-EXTERN int 	Tcldom_SafeInit(Tcl_Interp *interp);
+TCLDOMAPI int Tcldom_Init(Tcl_Interp *interp);
+TCLDOMAPI int Tcldom_SafeInit(Tcl_Interp *interp);
 
 void		TclDomDeleteNode(Tcl_Interp *interp,
 		    TclDomInterpData *interpDataPtr, TclDomNode *nodePtr);
@@ -516,9 +518,6 @@ void	TclDomSetDomError(Tcl_Interp *interp,
 extern void TclDomRegisterLiveList( ... )
 */
 
-# undef TCL_STORAGE_CLASS
-# define TCL_STORAGE_CLASS DLLIMPORT
-
 /* Tcl version compatibility macros:
  */
 #ifndef CONST84			/* added in TIP 27 */ 
